@@ -3,7 +3,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::ReadmeAnyFromPod;
 {
-  $Dist::Zilla::Plugin::ReadmeAnyFromPod::VERSION = '0.133290';
+  $Dist::Zilla::Plugin::ReadmeAnyFromPod::VERSION = '0.133360';
 }
 # ABSTRACT: Automatically convert POD to a README in any format for Dist::Zilla
 
@@ -16,6 +16,7 @@ use Moose;
 use MooseX::Has::Sugar;
 use PPI::Document;
 use PPI::Token::Pod;
+use Path::Tiny 0.004;
 use Pod::Simple::HTML 3.23;
 use Pod::Simple::Text 3.23;
 use Scalar::Util 'blessed';
@@ -197,7 +198,6 @@ sub after_build {
 
         my $content = $self->get_readme_content();
 
-        require Path::Tiny;
         my $file = $self->zilla->root->file($filename);
         if (-e $file) {
             $self->log("overriding $filename in root");
@@ -306,7 +306,7 @@ Dist::Zilla::Plugin::ReadmeAnyFromPod - Automatically convert POD to a README in
 
 =head1 VERSION
 
-version 0.133290
+version 0.133360
 
 =head1 SYNOPSIS
 
